@@ -20,10 +20,10 @@ from filebrowser_safe.functions import url_to_path
 
 class FileBrowseWidget(Input):
     input_type = 'text'
-    
+
     class Media:
         js = (os.path.join(URL_FILEBROWSER_MEDIA, 'js/AddFileBrowser.js'), )
-    
+
     def __init__(self, attrs=None):
         self.directory = attrs.get('directory', '')
         self.extensions = attrs.get('extensions', '')
@@ -32,7 +32,7 @@ class FileBrowseWidget(Input):
             self.attrs = attrs.copy()
         else:
             self.attrs = {}
-    
+
     def render(self, name, value, attrs=None):
         if value is None:
             value = ""
@@ -48,16 +48,16 @@ class FileBrowseWidget(Input):
                 final_attrs['directory'] = os.path.split(value.path_relative_directory)[0]
             except:
                 pass
-        return render_to_string("filebrowser/custom_field.html", locals())
+        return render_to_string("filebrowser/custom_field.html", dict(locals(), MEDIA_URL=MEDIA_URL))
 
 
 class FileBrowseFormField(forms.CharField):
     widget = FileBrowseWidget
-    
+
     default_error_messages = {
         'extension': _(u'Extension %(ext)s is not allowed. Only %(allowed)s is allowed.'),
     }
-    
+
     def __init__(self, max_length=None, min_length=None,
                  directory=None, extensions=None, format=None,
                  *args, **kwargs):
@@ -68,7 +68,7 @@ class FileBrowseFormField(forms.CharField):
             self.format = format or ''
             self.extensions = extensions or EXTENSIONS.get(format)
         super(FileBrowseFormField, self).__init__(*args, **kwargs)
-    
+
     def clean(self, value):
         value = super(FileBrowseFormField, self).clean(value)
         if value == '':
@@ -81,30 +81,30 @@ class FileBrowseFormField(forms.CharField):
 
 class FileBrowseField(Field):
     __metaclass__ = models.SubfieldBase
-    
+
     def __init__(self, *args, **kwargs):
         self.directory = kwargs.pop('directory', '')
         self.extensions = kwargs.pop('extensions', '')
         self.format = kwargs.pop('format', '')
         return super(FileBrowseField, self).__init__(*args, **kwargs)
-    
+
     def to_python(self, value):
         if not value or isinstance(value, FileObject):
             return value
         return FileObject(url_to_path(value))
-    
+
     def get_db_prep_value(self, value, connection, prepared=False):
         if value is None:
             return None
         return unicode(value)
-        
-    
+
+
     def get_manipulator_field_objs(self):
         return [oldforms.TextField]
-    
+
     def get_internal_type(self):
         return "CharField"
-    
+
     def formfield(self, **kwargs):
         attrs = {}
         attrs["directory"] = self.directory
